Change Log — ghmdlib - v0.1.0 Documentation

# Change Log

- 0.1.0 - Initial release for the ghmdlib fork of the ghmd project. by j_berendt at 2025-12-31 09:18:09

      New features:
      The original ghmd project was forked to provide additional Markdown to HTML
      conversion features, specifically for our docp project suite. However, as
      the library is generalised, it can be integrated into any project.

      - An installable library has been built in for cross-project integration.
      - The command line program has been updated to include additional features
        including a --preview flag which auto-opens the converted HTML file in a
        web browser immediately.
      - An 'offline' mode has been added for secure environment deployments or
        environments with limited internet access.
      - A 'download' feature has been added for downloading (or updating) CSS
        files locally, for use with the offline mode.

      Testing:
      - A new testing suite has been added.
      - All tests complete successfully with 100% (applicable) code coverage.

      Released: 2026-01-05

- 0.1.0 - Initial commit and code restructuring for ghmdlib. by j_berendt at 2025-12-31 05:59:47

- Merge pull request #6 from roman910dev:fix-readme by Román Via-Dufresne Saus at 2025-12-30 12:41:34

      Fix-readme

- chore(repo): :bookmark: `v1.0.1` by Román Via-Dufresne Saus at 2025-12-30 12:40:14

- fix(repo): :memo: link to npm in readme by Román Via-Dufresne Saus at 2025-12-30 12:39:07

- Merge pull request #5 from roman910dev:ghmd-js by Román Via-Dufresne Saus at 2025-12-29 13:16:26

      ghmd-js

- fix(node): :package: `package.json` minor fixes by Román Via-Dufresne Saus at 2025-12-28 19:59:02

- fix(node): :adhesive_bandage: remove import main check by Román Via-Dufresne Saus at 2025-12-28 19:17:18

- chore(node): :package: add `engines` to `package.json` by Román Via-Dufresne Saus at 2025-12-28 19:16:44

- fix(node): :zap: make `index.js` executable by Román Via-Dufresne Saus at 2025-12-28 19:07:08

- fix(node): :zap: add shebang to `index.js` by Román Via-Dufresne Saus at 2025-12-28 19:06:06

- fix(node): :truck: rename node package to `ghmd-js` by Román Via-Dufresne Saus at 2025-12-28 19:04:15

      as there's already an npm package published for `ghmd`

- Merge pull request #4 from roman910dev:node-port by Román Via-Dufresne Saus at 2025-12-26 20:25:48

      Node-port

- style(repo): :art: format files by Román Via-Dufresne Saus at 2025-12-26 20:24:15

- chore: :bookmark: `v1.0.0` by Román Via-Dufresne Saus at 2025-12-26 20:23:57

- chore(node): :package: package metadata by Román Via-Dufresne Saus at 2025-12-26 20:23:09

- feat(repo): :hammer: add child readmes on `prepare` by Román Via-Dufresne Saus at 2025-12-26 20:15:45

- fix(python): :construction_worker: github action by Román Via-Dufresne Saus at 2025-12-26 20:08:02

      use uv, oidc and new file structure

- fix(node): :construction_worker: github action by Román Via-Dufresne Saus at 2025-12-26 20:03:56

- fix(node): :package: include `README.md` in package by Román Via-Dufresne Saus at 2025-12-26 20:03:23

- fix(python): :package: build config by Román Via-Dufresne Saus at 2025-12-26 20:02:05

- docs(repo): :memo: update `README` to include Node.js port info by Román Via-Dufresne Saus at 2025-12-25 21:48:10

- fix(repo): :construction_worker: github action tag triggers by Román Via-Dufresne Saus at 2025-12-25 21:36:37

- feat(node): :package: add `jsr.json` by Román Via-Dufresne Saus at 2025-12-25 21:27:40

- feat(node): :construction_worker: add `publish-node` github action by Román Via-Dufresne Saus at 2025-12-25 21:22:23

- feat(python): :construction_worker: migrate `publish` github action to `publish-python` by Román Via-Dufresne Saus at 2025-12-25 21:18:11

- feat(repo): :recycle: move shared string literals to `/shared/strings.json` by Román Via-Dufresne Saus at 2025-12-24 20:22:47

- feat(repo): :test_tube: implement `test` npm script by Román Via-Dufresne Saus at 2025-12-24 20:22:00

- feat(repo): :wrench: add `format` and `postinstall` npm scripts by Román Via-Dufresne Saus at 2025-12-24 20:05:45

- feat(repo): :sparkles: add `prepare` script that copies `shared` dir to child packages by Román Via-Dufresne Saus at 2025-12-24 19:41:42

- refactor(repo): :truck: rename `common` dir to `shared` by Román Via-Dufresne Saus at 2025-12-24 16:32:17

- style(python): :art: format files by Román Via-Dufresne Saus at 2025-11-27 10:51:58

- chore(python): :technologist: add `ruff` by Román Via-Dufresne Saus at 2025-11-27 10:47:49

- fix(python): :bug: `publish` gh action by Román Via-Dufresne Saus at 2025-10-19 19:37:25

- test(node): :white_check_mark: add node tests by Román Via-Dufresne Saus at 2025-10-17 13:35:41

- fix(node): :bug: template path by Román Via-Dufresne Saus at 2025-10-17 13:35:22

- feat(node): :sparkles: add node implementation by Román Via-Dufresne Saus at 2025-10-17 13:16:42

- fix(python): :adhesive_bandage: remove log by Román Via-Dufresne Saus at 2025-10-17 13:11:56

- test(test): :white_check_mark: html titles by Román Via-Dufresne Saus at 2025-10-17 13:11:20

- fix(python): :bug: template path by Román Via-Dufresne Saus at 2025-10-17 11:58:00

- test(test): :white_check_mark: add missing tests by Román Via-Dufresne Saus at 2025-10-16 17:41:14

- test(repo): :white_check_mark: add first test using vitest by Román Via-Dufresne Saus at 2025-10-16 10:39:54

- chore(repo): :wrench: setup biome by Román Via-Dufresne Saus at 2025-10-16 10:39:08

- chore(repo): :wrench: setup repo-level node project by Román Via-Dufresne Saus at 2025-10-16 10:35:22

- refactor(python): :recycle: python package location by Román Via-Dufresne Saus at 2025-10-16 10:34:11

- chore: :bookmark: `v0.4.0` by Román Via-Dufresne Saus at 2025-09-28 22:06:36

- Merge pull request #3 from roman910dev:dev by Román Via-Dufresne Saus at 2025-09-28 22:01:47

      Dev

- ci: :construction_worker: add `publish.yml` github action by Román Via-Dufresne Saus at 2025-09-28 21:56:39

- fix: :pencil2: README typo by Román Via-Dufresne Saus at 2025-09-25 13:06:54

- feat: :sparkles: add help message by Román Via-Dufresne Saus at 2025-09-25 12:35:07

- feat: :sparkles: error when an invalid option is used by Román Via-Dufresne Saus at 2025-09-25 12:29:41

- Fix CHANGELOG.md by Román Via-Dufresne Saus at 2025-01-10 11:19:36

      `0.3.0` release date was wrong

- 0.3.0 by Román Via-Dufresne Saus at 2025-01-10 10:19:32

- 0.2.0 by roman910dev at 2024-01-27 09:18:16

- initial commit by roman910dev at 2024-01-26 14:06:57